==> common-0.0.49-20200709.085719-3-sources.jar: com/kangxin/doctor/worktable/dialog/CenterHintDialogSpe.java <==
package com.kangxin.doctor.worktable.dialog;

import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.Gravity;
import android.view.View;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.kangxin.common.R;

public class CenterHintDialogSpe extends Dialog {

    String titleText;
    String messageText;
    String rightText;
    String leftText;
    View.OnClickListener leftClick;
    View.OnClickListener rightClick;
    boolean isShow = true;
    boolean isTouchOutCancel;

    public CenterHintDialogSpe(@NonNull Context context) {
        super(context);
    }

    public CenterHintDialogSpe setTitle(String title) {
        this.titleText = title;
        return this;

    }

    public CenterHintDialogSpe setMessage(String message) {
        this.messageText = message;
        return this;
    }

    public CenterHintDialogSpe setRightText(String rightText) {
        this.rightText = rightText;
        return this;

    }

    public CenterHintDialogSpe setLeftText(String leftText) {
        this.leftText = leftText;
        return this;
    }

    public CenterHintDialogSpe bindLeftClick(View.OnClickListener leftClick) {
        this.leftClick = leftClick;
        return this;
    }

    public CenterHintDialogSpe bindRightClick(View.OnClickListener rightClick) {
        this.rightClick = rightClick;
        return this;
    }

    public CenterHintDialogSpe setShowCancel(boolean isShow) {
        this.isShow = isShow;
        return this;
    }

    public CenterHintDialogSpe setTouchOutCancel(boolean isCancel) {
        this.isTouchOutCancel = isCancel;
        return this;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.centerhint_dialog_layout);

        if (getWindow() != null) {
            getWindow().setGravity(Gravity.CENTER);
            getWindow().setLayout(-1, -2);
            getWindow().setBackgroundDrawable(null);
        }

        setCanceledOnTouchOutside(isTouchOutCancel);

        TextView title = findViewById(R.id.title);
        TextView message = findViewById(R.id.message);

        title.setText(titleText);
        message.setText(messageText);

        TextView cancel = findViewById(R.id.cancel);
        TextView ok = findViewById(R.id.ok);

        if (!TextUtils.isEmpty(rightText))
            ok.setText(rightText);

        if (!TextUtils.isEmpty(leftText))
            cancel.setText(leftText);

        View v = findViewById(R.id.divider);

        if (!isShow) {
            cancel.setVisibility(View.GONE);
            v.setVisibility(View.GONE);
        }

        if (leftClick != null)
            cancel.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    leftClick.onClick(v);
                    dismiss();
                }
            });

        else cancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
            }
        });

        if (rightClick != null)
            ok.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    rightClick.onClick(v);
                    dismiss();
                }
            });
        else ok.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
            }
        });

    }

}

==> common-0.2.9-20220930.091436-1-sources.jar: com/kangxin/doctor/worktable/dialog/CenterHintDialogSpe.java <==
package com.kangxin.doctor.worktable.dialog;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.Gravity;
import android.view.View;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.StyleRes;


import com.kangxin.common.R;

public class CenterHintDialogSpe extends AlertDialog {

    String titleText;
    String messageText;
    String rightText;
    String leftText;
    View.OnClickListener leftClick;
    View.OnClickListener rightClick;
    boolean isShow = true;
    boolean isTouchOutCancel;

    public CenterHintDialogSpe(@NonNull Context context) {
        super(context);
    }

    public CenterHintDialogSpe(@NonNull Context context, @StyleRes int themeResId) {
        super(context,themeResId);
    }



    public CenterHintDialogSpe setTitle(String title) {
        this.titleText = title;
        return this;

    }

    public CenterHintDialogSpe setMessage(String message) {
        this.messageText = message;
        return this;
    }

    public CenterHintDialogSpe setRightText(String rightText) {
        this.rightText = rightText;
        return this;

    }

    public CenterHintDialogSpe setLeftText(String leftText) {
        this.leftText = leftText;
        return this;
    }

    public CenterHintDialogSpe bindLeftClick(View.OnClickListener leftClick) {
        this.leftClick = leftClick;
        return this;
    }

    public CenterHintDialogSpe bindRightClick(View.OnClickListener rightClick) {
        this.rightClick = rightClick;
        return this;
    }

    public CenterHintDialogSpe setShowCancel(boolean isShow) {
        this.isShow = isShow;
        return this;
    }

    public CenterHintDialogSpe setTouchOutCancel(boolean isCancel) {
        this.isTouchOutCancel = isCancel;
        return this;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.centerhint_dialog_layout);


        if (getWindow() != null) {
            getWindow().setGravity(Gravity.CENTER);
            getWindow().setLayout(-1, -2);
            getWindow().setBackgroundDrawable(null);
        }

        setCanceledOnTouchOutside(isTouchOutCancel);

        TextView title = findViewById(R.id.title);
        TextView message = findViewById(R.id.message);

        title.setText(titleText);
        message.setText(messageText);

        TextView cancel = findViewById(R.id.cancel);
        TextView ok = findViewById(R.id.ok);

        if (!TextUtils.isEmpty(rightText))
            ok.setText(rightText);

        if (!TextUtils.isEmpty(leftText))
            cancel.setText(leftText);

        View v = findViewById(R.id.divider);

        if (!isShow) {
            cancel.setVisibility(View.GONE);
            v.setVisibility(View.GONE);
        }

        if (leftClick != null)
            cancel.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    leftClick.onClick(v);
                    dismiss();
                }
            });

        else cancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
            }
        });

        if (rightClick != null)
            ok.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    rightClick.onClick(v);
                    dismiss();
                }
            });
        else ok.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
            }
        });

    }

}
